@@ -172,7 +172,7 @@ load_config (void)
   static_content = g_key_file_new ();
 
   if (!g_key_file_load_from_file (static_content,
-				  "/usr/share/belltower/static.ini",
+				  "/opt/belltower/static.ini",
 				  G_KEY_FILE_NONE,
 				  NULL))
     {
@@ -406,9 +406,14 @@ add_button (char *label,
 {
   GtkWidget *button;
 
+#if 0
+  /* We used to put all the buttons into the app menu as well,
+   * but that seems like overkill.
+   */
   button = gtk_button_new_with_label (label);
   g_signal_connect (button, "clicked", G_CALLBACK (callback), NULL);
   hildon_app_menu_append (menu, GTK_BUTTON (button));
+#endif
   button = hildon_button_new_with_text (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT,
 					HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 					label, NULL);
@@ -915,7 +920,7 @@ parse_dove (ParseDoveCallback callback,
 	    gpointer data,
 	    gchar *dialogue_title)
 {
-  FILE *dove = fopen("/usr/share/belltower/dove.txt", "r");
+  FILE *dove = fopen("/opt/belltower/dove.txt", "r");
   char tower_rec[4096];
   tower result;
   char *i;
@@ -1524,7 +1529,7 @@ main(int argc, char **argv)
   gtk_window_set_title (GTK_WINDOW (window), "Belltower");
   g_signal_connect (G_OBJECT (window), "delete_event", G_CALLBACK (gtk_main_quit), NULL);
 
-  bell_picture = gdk_pixbuf_new_from_file ("/usr/share/belltower/bells1.jpg", NULL);
+  bell_picture = gdk_pixbuf_new_from_file ("/opt/belltower/bells1.jpg", NULL);
 
   buttons = gtk_vbox_new (TRUE, 0);
   menu = HILDON_APP_MENU (hildon_app_menu_new ());
@@ -1534,13 +1539,12 @@ main(int argc, char **argv)
   add_button ("Bookmarks", show_bookmarks);
   add_button ("By area", towers_by_area);
   add_button ("Search", tower_search);
-  /* This won't be a button on the main screen
-   * for always, but we'll put it there for now
-   * to work around a hildon bug.
-   */
-  add_button ("Settings", settings_dialogue);
 
   /* extra buttons for the app menu */
+  button = gtk_button_new_with_label ("Settings");
+  g_signal_connect (button, "clicked", G_CALLBACK (settings_dialogue), NULL);
+  hildon_app_menu_append (menu, GTK_BUTTON (button));
+
   button = gtk_button_new_with_label ("Credits");
   g_signal_connect (button, "clicked", G_CALLBACK (show_credits), NULL);
   hildon_app_menu_append (menu, GTK_BUTTON (button));
